Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ProcessWorkshopDefinition ¶
func ProcessWorkshopDefinition(yamlData []byte, dataValueFlags yttcmd.DataValuesFlags) ([]byte, error)
Types ¶
type FilesExportOptions ¶
type FilesExportOptions struct {
Repository string
WorkshopFile string
WorkshopVersion string
DataValuesFlags yttcmd.DataValuesFlags
}
func (*FilesExportOptions) Export ¶
func (o *FilesExportOptions) Export(workshopDir string) error
func (*FilesExportOptions) Run ¶
func (o *FilesExportOptions) Run(args []string) error
type FilesPublishOptions ¶
type FilesPublishOptions struct {
Image string
Repository string
WorkshopFile string
ExportWorkshop string
WorkshopVersion string
RegistryFlags imgpkgcmd.RegistryFlags
DataValuesFlags yttcmd.DataValuesFlags
}
func (*FilesPublishOptions) Publish ¶
func (o *FilesPublishOptions) Publish(workshopDir string) error
func (*FilesPublishOptions) Run ¶
func (o *FilesPublishOptions) Run(args []string) error
type WorkshopNewOptions ¶
type WorkshopNewOptions struct {
Template string
Name string
Title string
Description string
Image string
TargetDirectory string
Overwrite bool
WithKubernetesAccess bool
WithGitHubAction bool
WithVirtualCluster bool
WithDockerDaemon bool
WithImageRegistry bool
WithKubernetesConsole bool
WithEditor bool
WithTerminal bool
}
func (*WorkshopNewOptions) Run ¶
func (o *WorkshopNewOptions) Run(args []string) error
If o.TargetDirectory is provided, we will use that as the directory to be used, otherwise a new one will be created
Click to show internal directories.
Click to hide internal directories.